@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-__author__ = '陈章'
-__date__ = '2019-04-25 11:34'
+__author__ = "陈章"
+__date__ = "2019-04-25 11:34"
 import logging
 import os
 import pickle
@@ -14,18 +14,23 @@ from python_common_tools.compress import get_md5
 
 
 class Cache:
-
     @classmethod
-    def cache_function(cls, cache_dir, is_method=False, before_func=None, end_func=None):
+    def cache_function(
+        cls, cache_dir, is_method=False, before_func=None, end_func=None
+    ):
         def outer(f):
             @wraps(f)
             def inner(*args, **kwargs):
                 # prepare cache_file
                 fname = f.__qualname__
                 argv_str = cls.get_argv_str(args, kwargs, is_method)
-                cache_dir_real = '{cache_dir}/{fname}'.format(cache_dir=cache_dir, fname=fname)
+                cache_dir_real = "{cache_dir}/{fname}".format(
+                    cache_dir=cache_dir, fname=fname
+                )
                 os.makedirs(cache_dir_real, exist_ok=True)
-                cache_file = '{cache_dir_real}/{name}.pkl'.format(cache_dir_real=cache_dir_real, name=get_md5(argv_str))
+                cache_file = "{cache_dir_real}/{name}.pkl".format(
+                    cache_dir_real=cache_dir_real, name=get_md5(argv_str)
+                )
                 if before_func:
                     before_func()
                 r = cls.exec_func(cache_file, fname, f, args, kwargs)
@@ -40,22 +45,32 @@ class Cache:
     @classmethod
     def get_argv_str(cls, args, kwargs, is_method=False):
         if is_method:
-            return '{arg}_{kwa}'.format(arg=quote_plus(str(args[1:])), kwa=quote_plus(str(kwargs)))
+            return "{arg}_{kwa}".format(
+                arg=quote_plus(str(args[1:])), kwa=quote_plus(str(kwargs))
+            )
         else:
-            return '{arg}_{kwa}'.format(arg=quote_plus(str(args)), kwa=quote_plus(str(kwargs)))
+            return "{arg}_{kwa}".format(
+                arg=quote_plus(str(args)), kwa=quote_plus(str(kwargs))
+            )
 
     @classmethod
     def exec_func(cls, cache_file, fname, f, args, kwargs):
         # exec func
         if not os.path.exists(cache_file):
-            logger.debug('exec func {fname} {args} {kwargs}'.format(fname=fname, args=args, kwargs=kwargs))
+            logger.debug(
+                "exec func {fname} {args} {kwargs}".format(
+                    fname=fname, args=args, kwargs=kwargs
+                )
+            )
             r = f(*args, **kwargs)
             cls.write_to_cache_file(cache_file, r)
         r = cls.read_from_cache_file(cache_file)
         return r
 
     @classmethod
-    def cache_daily_function(cls, cache_dir, is_method=False, before_func=None, end_func=None):
+    def cache_daily_function(
+        cls, cache_dir, is_method=False, before_func=None, end_func=None
+    ):
         def outer(f):
             @wraps(f)
             def inner(*args, **kwargs):
@@ -63,9 +78,13 @@ class Cache:
                 fname = f.__qualname__
                 today = datetime.now().strftime("%Y%m%d")
                 argv_str = cls.get_argv_str(args, kwargs, is_method)
-                cache_dir_real = '{cache_dir}/{fname}/{today}'.format(cache_dir=cache_dir, fname=fname, today=today)
+                cache_dir_real = "{cache_dir}/{fname}/{today}".format(
+                    cache_dir=cache_dir, fname=fname, today=today
+                )
                 os.makedirs(cache_dir_real, exist_ok=True)
-                cache_file = '{cache_dir_real}/{name}.pkl'.format(cache_dir_real=cache_dir_real, name=get_md5(argv_str))
+                cache_file = "{cache_dir_real}/{name}.pkl".format(
+                    cache_dir_real=cache_dir_real, name=get_md5(argv_str)
+                )
                 if before_func:
                     before_func()
                 r = cls.exec_func(cache_file, fname, f, args, kwargs)
@@ -79,14 +98,14 @@ class Cache:
 
     @classmethod
     def read_from_cache_file(cls, cache_file):
-        r_cache_file = open(cache_file, 'rb')
+        r_cache_file = open(cache_file, "rb")
         r = pickle.load(r_cache_file)
         r_cache_file.close()
         return r
 
     @classmethod
     def write_to_cache_file(cls, cache_file, r):
-        w_cache_file = open(cache_file, 'wb')
+        w_cache_file = open(cache_file, "wb")
         pickle.dump(r, w_cache_file)
         w_cache_file.close()
 
@@ -98,9 +117,13 @@ class Cache:
                 # prepare cache_file
                 fname = f.__qualname__
                 argv_str = cls.get_argv_str(args, kwargs, is_method)
-                cache_dir_real = '{cache_dir}/{fname}'.format(cache_dir=cache_dir, fname=fname)
+                cache_dir_real = "{cache_dir}/{fname}".format(
+                    cache_dir=cache_dir, fname=fname
+                )
                 os.makedirs(cache_dir_real, exist_ok=True)
-                cache_file = '{cache_dir_real}/{name}.pkl'.format(cache_dir_real=cache_dir_real, name=get_md5(argv_str))
+                cache_file = "{cache_dir_real}/{name}.pkl".format(
+                    cache_dir_real=cache_dir_real, name=get_md5(argv_str)
+                )
                 if os.path.exists(cache_file):
                     return True
                 cls.exec_func(cache_file, fname, f, args, kwargs)
